@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1+
 /*
- * Copyright 2019 Red Hat, Inc.
+ * Copyright (C) 2019 Red Hat, Inc.
  */
 
 #ifndef __NM_TEAM_UITLS_H__
@@ -11,6 +11,7 @@
 #endif
 
 #include "nm-glib-aux/nm-value-type.h"
+#include "nm-core-internal.h"
 
 struct _NMSetting;
 
@@ -277,17 +278,10 @@ NMTeamSetting *_nm_setting_get_team_setting (struct _NMSetting *setting);
 
 /*****************************************************************************/
 
-#include "nm-connection.h"
-#include "nm-core-internal.h"
-
-GVariant *_nm_team_settings_property_to_dbus (const NMSettInfoSetting *sett_info,
-                                              guint property_idx,
-                                              NMConnection *connection,
-                                              NMSetting *setting,
-                                              NMConnectionSerializationFlags flags,
-                                              const NMConnectionSerializationOptions *options);
-
-void _nm_team_settings_property_from_dbus_link_watchers (GVariant *dbus_value,
-                                                         GValue *prop_value);
+extern const NMSettInfoPropertType nm_sett_info_propert_type_team_b;
+extern const NMSettInfoPropertType nm_sett_info_propert_type_team_i;
+extern const NMSettInfoPropertType nm_sett_info_propert_type_team_s;
+extern const NMSettInfoPropertType nm_sett_info_propert_type_team_as;
+extern const NMSettInfoPropertType nm_sett_info_propert_type_team_link_watchers;
 
 #endif /* __NM_TEAM_UITLS_H__ */
