@@ -315,6 +315,9 @@ gboolean nm_ppdirect_equal (gconstpointer a, gconstpointer b);
 
 /*****************************************************************************/
 
+guint nm_gbytes_hash (gconstpointer p);
+#define nm_gbytes_equal g_bytes_equal
+
 guint nm_pgbytes_hash (gconstpointer p);
 gboolean nm_pgbytes_equal (gconstpointer a, gconstpointer b);
 
