@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1+
 /*
- * Copyright 2017 - 2018 Red Hat, Inc.
+ * Copyright (C) 2017 - 2018 Red Hat, Inc.
  */
 
 #include "nm-default.h"
@@ -46,6 +46,7 @@
 #include "nm-setting-user.h"
 #include "nm-setting-vlan.h"
 #include "nm-setting-vpn.h"
+#include "nm-setting-vrf.h"
 #include "nm-setting-vxlan.h"
 #include "nm-setting-wifi-p2p.h"
 #include "nm-setting-wimax.h"
@@ -387,6 +388,12 @@ const NMMetaSettingInfo nm_meta_setting_infos[] = {
 		.setting_name =             NM_SETTING_VPN_SETTING_NAME,
 		.get_setting_gtype =        nm_setting_vpn_get_type,
 	},
+	[NM_META_SETTING_TYPE_VRF] = {
+		.meta_type =                NM_META_SETTING_TYPE_VRF,
+		.setting_priority =         NM_SETTING_PRIORITY_HW_BASE,
+		.setting_name =             NM_SETTING_VRF_SETTING_NAME,
+		.get_setting_gtype =        nm_setting_vrf_get_type,
+	},
 	[NM_META_SETTING_TYPE_VXLAN] = {
 		.meta_type =                NM_META_SETTING_TYPE_VXLAN,
 		.setting_priority =         NM_SETTING_PRIORITY_HW_BASE,
